@@ -1,4 +1,17 @@
 from .version import __version__
+
+from .augmenting import (
+    repeat_first,
+    prepend,
+    prepend_if,
+    append,
+    append_if,
+    alternate_with,
+    ensure_contains,
+    extend,
+)
+
+
 from .selecting import (
     retain_if,
     reject_if,
@@ -18,10 +31,20 @@ from .searching import (
     nth_matching,
 )
 
-
+from .combining import (
+    join_with
+)
 
 __all__ = [
     "__version__",
+    "repeat_first",
+    "prepend",
+    "prepend_if",
+    "append",
+    "append_if",
+    "alternate_with",
+    "ensure_contains",
+    "extend",
     "retain_if",
     "reject_if",
     "retain_truthy",
@@ -35,4 +58,5 @@ __all__ = [
     "take_between_inclusive_values",
     "first_matching",
     "nth_matching",
+    "join_with",
 ]
